### 0.10.3 {small}`2023-10-31`

```{rubric} Bugfix
```
* Prevent pandas from causing infinite recursion when setting a slice of a categorical column {pr}`1211` {user}`flying-sheep`

```{rubric} Documentation
```
* Stop showing “Support for Awkward Arrays is currently experimental” warnings when
  reading, concatenating, slicing, or transposing AnnData objects {pr}`1182` {user}`flying-sheep`

```{rubric} Other updates
```
* Fail canary CI job when tests raise unexpected warnings. {pr}`1182` {user}`flying-sheep`
